.. :changelog:

History
-------

0.0.1 (2015-11-24)
---------------------

* First release on PyPI.

0.0.2 (2015-12-08)
---------------------

* Remove old LinearRegression class.
* Add residuals, qq, scree, and principle components pairwise plots.
* Add stats function for calculating SSE, adjusted R2, coefficients standard
  error, t-values, p-values, F-statistic, and residuals.
* Add a summary function for summarizing stats on linear models.
* Add a PCR class for performing principle components regression.
